@@ -491,7 +491,7 @@ void Process::setParent(Process* parent)
     d->parent = parent;
 }
 
-void Process::setLogin(QString login)
+void Process::setLogin(const QString &login)
 {
     if(d->login == login) return;
     d->login = login;
@@ -560,7 +560,7 @@ void Process::setTracerpid(qlonglong tracerpid)
     d->changes |= Process::Tracerpid;
 }
 
-void Process::setTty(QByteArray tty)
+void Process::setTty(const QByteArray &tty)
 {
     if(d->tty == tty) return;
     d->tty = tty;
@@ -654,13 +654,13 @@ void Process::setVmURSS(qlonglong _vmURSS) {
     d->changes |= Process::VmURSS;
 }
 
-void Process::setName(QString _name) {
+void Process::setName(const QString &_name) {
     if(d->name == _name) return;
     d->name = _name;
     d->changes |= Process::Name;
 }
 
-void Process::setCommand(QString _command) {
+void Process::setCommand(const QString &_command) {
     if(d->command == _command) return;
     d->command = _command;
     d->changes |= Process::Command;
@@ -765,4 +765,4 @@ void Process::setChanges(KSysGuard::Process::Change changes)
     d->changes = changes;
 }
 
-}
\ No newline at end of file
+}
